@@ -6,9 +6,9 @@
 
 #include "QXmppIqHandling.h"
 #include "QXmppUtils.h"
+#include "QXmppUtils_p.h"
 
 #include <QDomElement>
-#include <QStringBuilder>
 
 constexpr QStringView XMLNS_BLOCKING = u"urn:xmpp:blocking";
 
@@ -28,10 +28,8 @@ static void makeUnique(T &vec)
 static QVector<QString> parseItems(const QDomElement &el)
 {
     QVector<QString> jids;
-    for (auto item = el.firstChildElement("item");
-         !item.isNull();
-         item = item.nextSiblingElement("item")) {
-        jids.append(item.attribute("jid"));
+    for (const auto &item : iterChildElements(el, u"item")) {
+        jids.append(item.attribute(QStringLiteral("jid")));
     }
     return jids;
 }
@@ -39,8 +37,8 @@ static QVector<QString> parseItems(const QDomElement &el)
 static void serializeItems(QXmlStreamWriter *writer, const QVector<QString> &jids)
 {
     for (const auto &jid : jids) {
-        writer->writeStartElement("item");
-        writer->writeAttribute("jid", jid);
+        writer->writeStartElement(QSL65("item"));
+        writer->writeAttribute(QSL65("jid"), jid);
         writer->writeEndElement();
     }
 }
@@ -57,7 +55,7 @@ public:
     }
     void toXmlElementFromChild(QXmlStreamWriter *writer) const override
     {
-        writer->writeStartElement("blocklist");
+        writer->writeStartElement(QSL65("blocklist"));
         writer->writeDefaultNamespace(XMLNS_BLOCKING.toString());
         serializeItems(writer, jids);
         writer->writeEndElement();
@@ -84,7 +82,7 @@ public:
     }
     void toXmlElementFromChild(QXmlStreamWriter *writer) const override
     {
-        writer->writeStartElement(QStringLiteral("block"));
+        writer->writeStartElement(QSL65("block"));
         writer->writeDefaultNamespace(XMLNS_BLOCKING.toString());
         serializeItems(writer, jids);
         writer->writeEndElement();
@@ -112,7 +110,7 @@ public:
 
     void toXmlElementFromChild(QXmlStreamWriter *writer) const override
     {
-        writer->writeStartElement(QStringLiteral("unblock"));
+        writer->writeStartElement(QSL65("unblock"));
         writer->writeDefaultNamespace(XMLNS_BLOCKING.toString());
         serializeItems(writer, jids);
         writer->writeEndElement();
@@ -125,8 +123,7 @@ public:
 };
 
 // Manager data
-struct QXmppBlockingManagerPrivate
-{
+struct QXmppBlockingManagerPrivate {
     std::optional<QVector<QString>> blocklist;
     std::vector<QXmppPromise<QXmppBlockingManager::BlocklistResult>> openFetchBlocklistPromises;
 };
@@ -356,16 +353,14 @@ QStringList QXmppBlockingManager::discoveryFeatures() const
     return { XMLNS_BLOCKING.toString() };
 }
 
-void QXmppBlockingManager::setClient(QXmppClient *newClient)
+void QXmppBlockingManager::onRegistered(QXmppClient *client)
 {
-    // disconnect from old client
-    if (client()) {
-        disconnect(client(), &QXmppClient::connected, this, &QXmppBlockingManager::onConnected);
-    }
+    connect(client, &QXmppClient::connected, this, &QXmppBlockingManager::onConnected);
+}
 
-    QXmppClientExtension::setClient(newClient);
-
-    connect(client(), &QXmppClient::connected, this, &QXmppBlockingManager::onConnected);
+void QXmppBlockingManager::onUnregistered(QXmppClient *oldClient)
+{
+    disconnect(oldClient, &QXmppClient::connected, this, &QXmppBlockingManager::onConnected);
 }
 
 bool QXmppBlockingManager::handleStanza(const QDomElement &stanza, const std::optional<QXmppE2eeMetadata> &)
@@ -557,9 +552,9 @@ QXmppBlocklist::BlockingState QXmppBlocklist::blockingState(const QString &jid)
         // Partially blocked:
         //  not possible
         checkBlockingJid(jid);
-        checkBlockingJid(user % u'@' % domain);
+        checkBlockingJid(user + u'@' + domain);
         checkBlockingJid(domain);
-        checkBlockingJid(domain % u'/' % resource);
+        checkBlockingJid(domain + u'/' + resource);
         break;
     case BareJid: {
         // Blocking:
@@ -579,7 +574,7 @@ QXmppBlocklist::BlockingState QXmppBlocklist::blockingState(const QString &jid)
             }
         }
 
-        checkPartiallyBlockingJid(domain % u'/' % resource);
+        checkPartiallyBlockingJid(domain + u'/' + resource);
         break;
     }
     case Domain: {
@@ -592,8 +587,8 @@ QXmppBlocklist::BlockingState QXmppBlocklist::blockingState(const QString &jid)
         checkBlockingJid(jid);
 
         // look for full/bare jids and domain+resource jids
-        QString userJidSubstring = u'@' % domain;
-        QString domainResourceSubstring = domain % u'/';
+        QString userJidSubstring = u'@' + domain;
+        QString domainResourceSubstring = domain + u'/';
 
         for (const auto &blockedJid : m_blocklist) {
             if (blockedJid.contains(userJidSubstring) || blockedJid.contains(domainResourceSubstring)) {
@@ -614,7 +609,7 @@ QXmppBlocklist::BlockingState QXmppBlocklist::blockingState(const QString &jid)
         checkBlockingJid(domain);
 
         // look for full/bare jids
-        QString userJidSubstring = u'@' % domain;
+        QString userJidSubstring = u'@' + domain;
         for (const auto &blockedJid : m_blocklist) {
             if (blockedJid.contains(userJidSubstring)) {
                 partiallyBlockingJids.append(blockedJid);
