@@ -1024,8 +1024,7 @@ QXmppTask<QXmppE2eeExtension::MessageDecryptResult> QXmppOmemoManager::decryptMe
             SendError::EncryptionError });
     }
 
-    auto omemoElement = message.omemoElement();
-    if (!omemoElement) {
+    if (!message.omemoElement()) {
         return makeReadyTask<MessageDecryptResult>(NotEncrypted());
     }
 
@@ -1157,9 +1156,11 @@ bool Manager::handleMessage(const QXmppMessage &message)
 {
     if (d->isStarted && message.omemoElement()) {
         auto future = d->decryptMessage(message);
-        future.then(this, [=](std::optional<QXmppMessage> optionalDecryptedMessage) mutable {
+        future.then(this, [this, message](std::optional<QXmppMessage> optionalDecryptedMessage) {
             if (optionalDecryptedMessage) {
                 injectMessage(std::move(*optionalDecryptedMessage));
+            } else {
+                Q_EMIT client() -> messageReceived(message);
             }
         });
 
